/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CdnZones = void 0;
const core_1 = require("@commerce-apps/core");
const USER_AGENT_HEADER = "user-agent";
const USER_AGENT_VALUE = "commerce-sdk@3.1.0;";
/**
* [CDN Zones](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=cdn-api-process-apis:Summary)
* ==================================
*
* *Extend your eCDN beyond Business Manager configuration.*<br />
*
*
* For instructions on how to retrieve access token for admin APIs: <a>https://developer.salesforce.com/docs/commerce/commerce-api/guide/authorization-for-admin-apis.html</a><br/><br/>
* Example with admin auth
*
* ```typescript
* import { Cdn, ClientConfig } from "commerce-sdk";
* // or
* const { Cdn, ClientConfig } = require("commerce-sdk");
*
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
*
* token = { access_token: 'INSERT_ACCESS_TOKEN_HERE' };
*
* clientConfig.headers['authorization'] = `Bearer ${token.access_token}`;
* const cdnZonesClient = new Cdn.CdnZones(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.0.30<br />
* Last Updated: <br />
* </span>

*

*/
class CdnZones extends core_1.BaseClient {
  /**
   *
   */
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/cdn/zones/{version}";
    }
  }
  /**
   * Create a new storefront zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.StorefrontZoneCreateEnvelope otherwise.
   *
   */
  createStorefrontZone(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/storefront-zones",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves zone information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.ZonesEnvelope otherwise.
   *
   */
  getZonesInfo(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["offset"] !== undefined) {
      queryParams["offset"] = optionParams["offset"];
    } else if (configParams["offset"] !== undefined) {
      queryParams["offset"] = configParams["offset"];
    }
    if (optionParams["limit"] !== undefined) {
      queryParams["limit"] = optionParams["limit"];
    } else if (configParams["limit"] !== undefined) {
      queryParams["limit"] = configParams["limit"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/info",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves all WAF groups accessible to the caller. Not applicable for zones using WAFv2. For any zones created after the 24.5 release, use the endpoints for WAF managed rulesets instead.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.WafGroupsEnvelope otherwise.
   *
   */
  getWafGroups(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/waf/groups",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates action or mode of a specific WAF group. Not applicable for zones using WAFv2. For any zones created after the 24.5 release, use the endpoints for WAF managed rulesets instead.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param groupId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.WafGroupEnvelope otherwise.
   *
   */
  updateWafGroup(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      groupId: optionParams["groupId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.put(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/waf/groups/{groupId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves WAF rules under the waf group specified by the caller. Not applicable for zones using WAFv2. For any zones created after the 24.5 release, use the endpoints for WAF managed rulesets instead.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param groupId - WAF Group that contains the WAF rules.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.WafRulesEnvelope otherwise.
   *
   */
  getWafRules(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    if (optionParams["groupId"] !== undefined) {
      queryParams["groupId"] = optionParams["groupId"];
    } else if (configParams["groupId"] !== undefined) {
      queryParams["groupId"] = configParams["groupId"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/waf/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves details of a specific WAF rule. Not applicable for zones using WAFv2. For any zones created after the 24.5 release, use the endpoints for WAF managed rulesets instead.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.WafRuleEnvelope otherwise.
   *
   */
  getWafRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/waf/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates action of a specific WAF rule. Not applicable for zones using WAFv2. For any zones created after the 24.5 release, use the endpoints for WAF managed rulesets instead.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.WafRuleEnvelope otherwise.
   *
   */
  updateWafRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.put(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/waf/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * (DEPRECATED) Retrieves existing firewall rules. This endpoint is deprecated. Requests return a 400 Bad Request response. Use [eCDN custom rules](https://developer.salesforce.com/docs/commerce/commerce-api/guide/cdn-zones-custom-rules.html) moving forward. Any existing firewall rules are accessible and can be updated using the custom rule endpoints.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.FirewallRulesEnvelope otherwise.
   *
   */
  getFirewallRules(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * (DEPRECATED) Creates a firewall rule. This endpoint is deprecated. Requests return a 400 Bad Request response. Use [eCDN custom rules](https://developer.salesforce.com/docs/commerce/commerce-api/guide/cdn-zones-custom-rules.html) moving forward. Any existing firewall rules are accessible and can be updated using the custom rule endpoints.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.FirewallRuleEnvelope otherwise.
   *
   */
  createFirewallRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * (DEPRECATED) Retrieve a specific firewall rule. This endpoint is deprecated. Requests return a 400 Bad Request response. Use [eCDN custom rules](https://developer.salesforce.com/docs/commerce/commerce-api/guide/cdn-zones-custom-rules.html) moving forward. Any existing firewall rules are accessible and can be updated using the custom rule endpoints.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.FirewallRuleEnvelope otherwise.
   *
   */
  getFirewallRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      firewallRuleId: optionParams["firewallRuleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall/rules/{firewallRuleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * (DEPRECATED) Update a specific firewall rule. This endpoint is deprecated. Requests return a 400 Bad Request response. Use [eCDN custom rules](https://developer.salesforce.com/docs/commerce/commerce-api/guide/cdn-zones-custom-rules.html) moving forward. Any existing firewall rules are accessible and can be updated using the custom rule endpoints.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.FirewallRuleEnvelope otherwise.
   *
   */
  updateFirewallRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      firewallRuleId: optionParams["firewallRuleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.put(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall/rules/{firewallRuleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * (DEPRECATED) Delete a specific firewall rule. This endpoint is deprecated. Requests return a 400 Bad Request response. Use [eCDN custom rules](https://developer.salesforce.com/docs/commerce/commerce-api/guide/cdn-zones-custom-rules.html) moving forward. Any existing firewall rules are accessible and can be updated using the custom rule endpoints.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param firewallRuleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteFirewallRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      firewallRuleId: optionParams["firewallRuleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall/rules/{firewallRuleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieve speed settings for a zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.SpeedSettingsEnvelope otherwise.
   *
   */
  getSpeedSettings(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/speed-settings",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Update speed settings for a zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.SpeedSettingsEnvelope otherwise.
   *
   */
  updateSpeedSettings(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/speed-settings",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieve security settings for a zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.SecuritySettingsEnvelope otherwise.
   *
   */
  getSecuritySettings(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/security-settings",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Update security settings for a zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.SecuritySettingsEnvelope otherwise.
   *
   */
  updateSecuritySettings(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/security-settings",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Request to purge the cache for the host given in the request body
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CachePurgeResponseEnvelope otherwise.
   *
   */
  cachePurge(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/cachepurge",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Request to enable or disable OCAPI Caching page rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.OCAPICachingToggleRequest otherwise.
   *
   */
  toggleOcapiCachingPageRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/ocapicachingpagerule",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves a list of certificates information for a zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CertificatesEnvelope otherwise.
   *
   */
  getCertificates(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    if (optionParams["offset"] !== undefined) {
      queryParams["offset"] = optionParams["offset"];
    } else if (configParams["offset"] !== undefined) {
      queryParams["offset"] = configParams["offset"];
    }
    if (optionParams["limit"] !== undefined) {
      queryParams["limit"] = optionParams["limit"];
    } else if (configParams["limit"] !== undefined) {
      queryParams["limit"] = configParams["limit"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/certificates",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Add Certificates For Zone
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CertificateEnvelope otherwise.
   *
   */
  addCertificateForZone(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/certificates",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * This action deletes a custom hostname and the certificate associated with it. Note that a valid certificate is necessary for a site to remain operational. DELETING AN IN-USE CERTIFICATE MAY RESULT IN DOWNTIME.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param certificateId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteCertificate(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      certificateId: optionParams["certificateId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/certificates/{certificateId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates the certificate for a given certificateId for a particular zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param certificateId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CertificateEnvelope otherwise.
   *
   */
  updateCertificate(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      certificateId: optionParams["certificateId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/certificates/{certificateId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Trigger the validation of a custom hostname.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param customHostnameId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CustomHostnameValidationEnvelope otherwise.
   *
   */
  validateCustomHostname(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      customHostnameId: optionParams["customHostnameId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/certificates/custom-hostnames/{customHostnameId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Create MRT rules.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.MRTRulesResponseEnvelope otherwise.
   *
   */
  createMrtRules(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/mrtrules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Update the MRT hostname or add MRT rules to the ruleset.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.MRTRulesResponseEnvelope otherwise.
   *
   */
  updateMrtRuleset(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/mrtrules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Get MRT rules associated with a zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.MRTRulesResponseEnvelope otherwise.
   *
   */
  getMrtRules(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/mrtrules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Delete the MRT ruleset specified for that particular zone.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param rulesetId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteMrtRuleset(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      rulesetId: optionParams["rulesetId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/mrtrules/{rulesetId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Delete an MRT rule in the specified ruleset.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param rulesetId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteMrtRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      rulesetId: optionParams["rulesetId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/mrtrules/{rulesetId}/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Update the expression and enable or disable an MRT rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param rulesetId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.MRTRulesResponseEnvelope otherwise.
   *
   */
  updateMrtRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      rulesetId: optionParams["rulesetId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/mrtrules/{rulesetId}/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Create Logpush ownership token file.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.LogpushOwnershipPostResponse otherwise.
   *
   */
  createLogpushOwnership(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/logpush/ownership",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Create Logpush job.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.LogpushEnvelope otherwise.
   *
   */
  createLogpushJob(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/logpush/jobs",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * List Logpush job.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.LogpushJobsEnvelope otherwise.
   *
   */
  listLogpushJob(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/logpush/jobs",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Get Logpush job details.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param jobId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.LogpushEnvelope otherwise.
   *
   */
  getLogpushJob(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      jobId: optionParams["jobId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/logpush/jobs/{jobId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Update Logpush job.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param jobId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.LogpushEnvelope otherwise.
   *
   */
  updateLogpushJob(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      jobId: optionParams["jobId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.put(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/logpush/jobs/{jobId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Delete Logpush job by job ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param jobId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteLogpushJob(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      jobId: optionParams["jobId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/logpush/jobs/{jobId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Creates a custom rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CustomRuleEnvelope otherwise.
   *
   */
  createCustomRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-custom/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves existing custom rules.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param offset -
   * @param limit - Maximum records to retrieve per request, not to exceed 50. Defaults to 25.
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CustomRulesEnvelope otherwise.
   *
   */
  getCustomRules(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    if (optionParams["offset"] !== undefined) {
      queryParams["offset"] = optionParams["offset"];
    } else if (configParams["offset"] !== undefined) {
      queryParams["offset"] = configParams["offset"];
    }
    if (optionParams["limit"] !== undefined) {
      queryParams["limit"] = optionParams["limit"];
    } else if (configParams["limit"] !== undefined) {
      queryParams["limit"] = configParams["limit"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-custom/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates the order of all existing custom rules.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CustomRulesEnvelope otherwise.
   *
   */
  updateOrderOfCustomRules(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-custom/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves a specific custom rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CustomRuleEnvelope otherwise.
   *
   */
  getCustomRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-custom/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates a specific custom rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.CustomRuleEnvelope otherwise.
   *
   */
  updateCustomRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-custom/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Deletes a specific custom rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteCustomRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-custom/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Creates a rate limiting rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.RateLimitingRuleEnvelope otherwise.
   *
   */
  createRateLimitingRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/rate-limiting/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves existing rate limiting rules.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.RateLimitingRulesEnvelope otherwise.
   *
   */
  getRateLimitingRules(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/rate-limiting/rules",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves a specific rate limiting rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.RateLimitingRuleEnvelope otherwise.
   *
   */
  getRateLimitingRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/rate-limiting/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates a specific rate limiting rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.RateLimitingRuleEnvelope otherwise.
   *
   */
  updateRateLimitingRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/rate-limiting/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Deletes a specific rate limiting rule.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param ruleId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteRateLimitingRule(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      ruleId: optionParams["ruleId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/rate-limiting/rules/{ruleId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Retrieves WAFv2 managed rulesets.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.WAFManagedRulesetsEnvelope otherwise.
   *
   */
  getWafManagedRulesets(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-managed/rulesets",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates WAFv2 managed ruleset.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param zoneId -
   * @param rulesetId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type CdnZones.WAFManagedRulesetEnvelope otherwise.
   *
   */
  updateWafManagedRuleset(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      zoneId: optionParams["zoneId"],
      rulesetId: optionParams["rulesetId"],
    };
    const queryParams = {};
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/zones/{zoneId}/firewall-managed/rulesets/{rulesetId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
}
exports.CdnZones = CdnZones;
//# sourceMappingURL=cdnZones.js.map
