/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShopperExperience = void 0;
const core_1 = require("@commerce-apps/core");
const USER_AGENT_HEADER = "user-agent";
const USER_AGENT_VALUE = "commerce-sdk@3.1.0;";
/**
* [Shopper Experience](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=shopper-experience:Summary)
* ==================================
*
* **<br />
*
*
* Example with shopper auth
*
* ```typescript
* import { Experience, ClientConfig, Customer, slasHelpers } from "commerce-sdk";
* // or
* const { Experience, ClientConfig, Customer, slasHelpers } = require("commerce-sdk");
*
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
*
* // must be registered in SLAS. On server, redirectURI is never called
* const redirectURI = "http://localhost:3000/callback";
* const slasClient = new Customer.ShopperLogin(clientConfig);
* token = await slasHelpers.loginGuestUser(slasClient, { redirectURI });
*
* clientConfig.headers['authorization'] = `Bearer ${token.access_token}`;
* const shopperExperienceClient = new Experience.ShopperExperience(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.0.5<br />
* Last Updated: <br />
* </span>

*

*/
class ShopperExperience extends core_1.BaseClient {
  /**
   *
   */
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/experience/shopper-experience/{version}";
    }
  }
  /**
    * Get Page Designer pages. The results will apply the visibility rules for each page's components, such as personalization or scheduled visibility.

Either `categoryId` or `productId` must be given in addition to `aspectTypeId`. Because only a single page-to-product and page-to-category assignment per aspect type can be authored today, the returned result contains one element at most.

**Important**: Currently, the Shopper Experience API can’t be used when the [storefront password protection](https://documentation.b2c.commercecloud.salesforce.com/DOC1/index.jsp?topic=%2Fcom.demandware.dochelp%2Fcontent%2Fb2c_commerce%2Ftopics%2Fpermissions%2Fb2c_storefront_password_protection.html&resultof=%22%73%74%6f%72%65%66%72%6f%6e%74%22%20%22%70%72%6f%74%65%63%74%69%6f%6e%22%20%22%70%72%6f%74%65%63%74%22%20) feature is enabled.

**Important**: Because this resource uses the GET method, you must not pass sensitive data (payment card information, for example) and must not perform any transactional processes within the server-side scripts that are run for the page and components.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param categoryId - Category identifier that is used for searching the page assignment. Must be provided if no `productId` is provided.
    * @param productId - Product identifier that is used for searching the page assignment. Must be provided if no `categoryId` is provided.
    * @param aspectTypeId - Aspect type identifier that is used for searching the page assignment in conjunction with either the `productId` or `categoryId`.
    * @param aspectAttributes - A JSON respresentation of aspect attributes. Each aspect attribute is a key/value pair. Aspect attributes serve as a runtime parameter contract between caller (for example, this API or the DWScript API) and callee (the page). This parameter must not contain more than 256 characters after URL decoding.
    * @param parameters - A free-form definition of parameters that influences the page rendering according to its implementation. This parameter must not contain more than 256 characters after URL decoding.
    * @param siteId -
    * @param locale - A descriptor to provide locale context for a geographical region by both a language and/or country code. The locale pattern in the query param follows the ISO 639-1 for the language code (e.g. en, de, fr) and ISO 3166-1 for the country code (e.g. US, DE, AT). The param can be a combination of language code and country code or can just refer to the language code.
Below are some valid examples:
- en-US
- de-AT
- de
- default
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperExperience.PageResult otherwise.
    *
    */
  getPages(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["categoryId"] !== undefined) {
      queryParams["categoryId"] = optionParams["categoryId"];
    } else if (configParams["categoryId"] !== undefined) {
      queryParams["categoryId"] = configParams["categoryId"];
    }
    if (optionParams["productId"] !== undefined) {
      queryParams["productId"] = optionParams["productId"];
    } else if (configParams["productId"] !== undefined) {
      queryParams["productId"] = configParams["productId"];
    }
    if (optionParams["aspectTypeId"] !== undefined) {
      queryParams["aspectTypeId"] = optionParams["aspectTypeId"];
    } else if (configParams["aspectTypeId"] !== undefined) {
      queryParams["aspectTypeId"] = configParams["aspectTypeId"];
    } else {
      throw new Error("Missing required query parameter: aspectTypeId");
    }
    if (optionParams["aspectAttributes"] !== undefined) {
      queryParams["aspectAttributes"] = optionParams["aspectAttributes"];
    } else if (configParams["aspectAttributes"] !== undefined) {
      queryParams["aspectAttributes"] = configParams["aspectAttributes"];
    }
    if (optionParams["parameters"] !== undefined) {
      queryParams["parameters"] = optionParams["parameters"];
    } else if (configParams["parameters"] !== undefined) {
      queryParams["parameters"] = configParams["parameters"];
    }
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    if (optionParams["locale"] !== undefined) {
      queryParams["locale"] = optionParams["locale"];
    } else if (configParams["locale"] !== undefined) {
      queryParams["locale"] = configParams["locale"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/pages",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Get a Page Designer page based on a single page ID. The results will apply the visibility rules for the page's components, such as personalization or scheduled visibility.

**Important**: Currently, the Shopper Experience API can’t be used when the [storefront password protection](https://documentation.b2c.commercecloud.salesforce.com/DOC1/index.jsp?topic=%2Fcom.demandware.dochelp%2Fcontent%2Fb2c_commerce%2Ftopics%2Fpermissions%2Fb2c_storefront_password_protection.html&resultof=%22%73%74%6f%72%65%66%72%6f%6e%74%22%20%22%70%72%6f%74%65%63%74%69%6f%6e%22%20%22%70%72%6f%74%65%63%74%22%20) feature is enabled.

**Important**: Because this resource uses the GET method, you must not pass sensitive data (payment card information, for example) and must not perform any transactional processes within the server-side scripts that are run for the page and components.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param pageId - Identifier for the requested page.
    * @param aspectAttributes - A JSON respresentation of aspect attributes. Each aspect attribute is a key/value pair. Aspect attributes serve as a runtime parameter contract between caller (for example, this API or the DWScript API) and callee (the page). This parameter must not contain more than 256 characters after URL decoding.
    * @param parameters - A free-form definition of parameters that influences the page rendering according to its implementation. This parameter must not contain more than 256 characters after URL decoding.
    * @param siteId -
    * @param locale - A descriptor to provide locale context for a geographical region by both a language and/or country code. The locale pattern in the query param follows the ISO 639-1 for the language code (e.g. en, de, fr) and ISO 3166-1 for the country code (e.g. US, DE, AT). The param can be a combination of language code and country code or can just refer to the language code.
Below are some valid examples:
- en-US
- de-AT
- de
- default
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperExperience.Page otherwise.
    *
    */
  getPage(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      pageId: optionParams["pageId"],
    };
    const queryParams = {};
    if (optionParams["aspectAttributes"] !== undefined) {
      queryParams["aspectAttributes"] = optionParams["aspectAttributes"];
    } else if (configParams["aspectAttributes"] !== undefined) {
      queryParams["aspectAttributes"] = configParams["aspectAttributes"];
    }
    if (optionParams["parameters"] !== undefined) {
      queryParams["parameters"] = optionParams["parameters"];
    } else if (configParams["parameters"] !== undefined) {
      queryParams["parameters"] = configParams["parameters"];
    }
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    if (optionParams["locale"] !== undefined) {
      queryParams["locale"] = optionParams["locale"];
    } else if (configParams["locale"] !== undefined) {
      queryParams["locale"] = configParams["locale"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/pages/{pageId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
}
exports.ShopperExperience = ShopperExperience;
//# sourceMappingURL=shopperExperience.js.map
