import { ISlasClient, TokenResponse } from "./slasClient";
/**
 * Converts a string into Base64 encoding
 *
 * @param unencoded - A string to be encoded
 * @returns Base64 encoded string
 */
export declare const stringToBase64: (unencoded: string) => string;
/**
 * Parse out the code and usid from a redirect url
 *
 * @param urlString - A url that contains `code` and `usid` query parameters, typically returned when calling a Shopper Login endpoint
 * @returns An object containing the code and usid.
 */
export declare const getCodeAndUsidFromUrl: (urlString: string) => {
    code: string;
    usid: string;
};
/**
 * Creates a random string to use as a code verifier. This code is created by the client and sent with both the authorization request (as a code challenge) and the token request.
 *
 * @returns code verifier
 */
export declare const createCodeVerifier: () => string;
/**
 * Encodes a code verifier to a code challenge to send to the authorization endpoint
 *
 * @param codeVerifier - random string to use as a code verifier
 * @returns code challenge
 */
export declare const generateCodeChallenge: (codeVerifier: string) => Promise<string>;
/**
 * Wrapper for the authorization endpoint. For federated login (3rd party IDP non-guest), the caller should redirect the user to the url in the url field of the returned object. The url will be the login page for the 3rd party IDP and the user will be sent to the redirectURI on success. Guest sessions return the code and usid directly with no need to redirect.
 *
 * @param slasClient - a configured instance of the ShopperLogin SDK client
 * @param codeVerifier - random string created by client app to use as a secret in the request
 * @param parameters - Request parameters used by the `authorizeCustomer` endpoint.
 * @param parameters.redirectURI - the location the client will be returned to after successful login with 3rd party IDP. Must be registered in SLAS.
 * @param parameters.hint? - optional string to hint at a particular IDP. Guest sessions are created by setting this to 'guest'
 * @param parameters.usid? - optional saved SLAS user id to link the new session to a previous session
 * @returns login url, user id and authorization code if available
 */
export declare function authorize(slasClient: ISlasClient, codeVerifier: string, parameters: {
    redirectURI: string;
    hint?: string;
    usid?: string;
}): Promise<{
    code: string;
    url: string;
    usid: string;
}>;
/**
 * A single function to execute the ShopperLogin Private Client Guest Login as described in the [API documentation](https://developer.salesforce.com/docs/commerce/commerce-api/guide/slas-private-client.html).
 *
 * @param slasClient - a configured instance of the ShopperLogin SDK client
 * @param credentials - client secret used for authentication
 * @param credentials.clientSecret - secret associated with client ID
 * @param usid? - optional Unique Shopper Identifier to enable personalization
 * @returns TokenResponse
 */
export declare function loginGuestUserPrivate(slasClient: ISlasClient, credentials: {
    clientSecret: string;
}, usid?: string): Promise<TokenResponse>;
/**
 * A single function to execute the ShopperLogin Public Client Guest Login with proof key for code exchange flow as described in the [API documentation](https://developer.salesforce.com/docs/commerce/commerce-api/guide/slas-public-client.html).
 *
 * @param slasClient a configured instance of the ShopperLogin SDK client.
 * @param parameters - parameters to pass in the API calls.
 * @param parameters.redirectURI - Per OAuth standard, a valid app route. Must be listed in your SLAS configuration. On server, this will not be actually called
 * @param parameters.usid? - Unique Shopper Identifier to enable personalization.
 * @returns TokenResponse
 */
export declare function loginGuestUser(slasClient: ISlasClient, parameters: {
    redirectURI: string;
    usid?: string;
}): Promise<TokenResponse>;
/**
 * A single function to execute the ShopperLogin Private Client Registered User B2C Login as described in the [API documentation](https://developer.salesforce.com/docs/commerce/commerce-api/guide/slas-private-client.html).
 *
 * @param slasClient - a configured instance of the ShopperLogin SDK client.
 * @param credentials - the shopper username and password for login and client secret for additional authentication
 * @param credentials.username - the id of the user to login with
 * @param credentials.password - the password of the user to login with
 * @param credentials.clientSecret - secret associated with client ID
 * @param parameters - parameters to pass in the API calls.
 * @param parameters.redirectURI - Per OAuth standard, a valid app route. Must be listed in your SLAS configuration. On server, this will not be actually called
 * @param parameters.usid? - optional Unique Shopper Identifier to enable personalization
 * @returns TokenResponse
 */
export declare function loginRegisteredUserB2Cprivate(slasClient: ISlasClient, credentials: {
    username: string;
    password: string;
    clientSecret: string;
}, parameters: {
    redirectURI: string;
    usid?: string;
}): Promise<TokenResponse>;
/**
 * A single function to execute the ShopperLogin Private Client Registered User B2C Login with proof key for code exchange flow as described in the [API documentation](https://developer.salesforce.com/docs/commerce/commerce-api/guide/slas-public-client.html).
 *
 * @param slasClient - a configured instance of the ShopperLogin SDK client.
 * @param credentials - the id and password to login with.
 * @param credentials.username - the id of the user to login with.
 * @param credentials.password - the password of the user to login with.
 * @param parameters - parameters to pass in the API calls.
 * @param parameters.redirectURI - Per OAuth standard, a valid app route. Must be listed in your SLAS configuration. On server, this will not be actually called. On browser, this will be called, but ignored.
 * @param parameters.usid? - Unique Shopper Identifier to enable personalization.
 * @returns TokenResponse
 */
export declare function loginRegisteredUserB2C(slasClient: ISlasClient, credentials: {
    username: string;
    password: string;
}, parameters: {
    redirectURI: string;
    usid?: string;
}): Promise<TokenResponse>;
/**
 * Exchange a refresh token for a new access token.
 *
 * @param slasClient - a configured instance of the ShopperLogin SDK client.
 * @param parameters - parameters to pass in the API calls.
 * @param parameters.refreshToken - a valid refresh token to exchange for a new access token (and refresh token).
 * @returns TokenResponse
 */
export declare function refreshAccessToken(slasClient: ISlasClient, parameters: {
    refreshToken: string;
}): Promise<TokenResponse>;
/**
 * Exchange a refresh token for a new access token.
 *
 * @param slasClient - a configured instance of the ShopperLogin SDK client.
 * @param credentials - client secret used for authentication
 * @param credentials.clientSecret - secret associated with client ID
 * @param parameters - parameters to pass in the API calls.
 * @param parameters.refreshToken - a valid refresh token to exchange for a new access token (and refresh token).
 * @returns TokenResponse
 */
export declare function refreshAccessTokenPrivate(slasClient: ISlasClient, credentials: {
    clientSecret: string;
}, parameters: {
    refreshToken: string;
}): Promise<TokenResponse>;
/**
 * Logout a shopper. The shoppers access token and refresh token will be revoked and if the shopper authenticated with ECOM the OCAPI JWT will also be revoked.
 *
 * @param slasClient - a configured instance of the ShopperLogin SDK client.
 * @param parameters - parameters to pass in the API calls.
 * @param parameters.accessToken - a valid access token to exchange for a new access token (and refresh token).
 * @param parameters.refreshToken - a valid refresh token to exchange for a new access token (and refresh token).
 * @returns TokenResponse
 */
export declare function logout(slasClient: ISlasClient, parameters: {
    accessToken: string;
    refreshToken: string;
}): Promise<TokenResponse>;
