/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Coupons = void 0;
const core_1 = require("@commerce-apps/core");
const USER_AGENT_HEADER = "user-agent";
const USER_AGENT_VALUE = "commerce-sdk@3.1.0;";
/**
* [Coupons](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=coupons:Summary)
* ==================================
*
* *Manage coupons for use in your storefront.*<br />
*
*
* For instructions on how to retrieve access token for admin APIs: <a>https://developer.salesforce.com/docs/commerce/commerce-api/guide/authorization-for-admin-apis.html</a><br/><br/>
* Example with admin auth
*
* ```typescript
* import { Pricing, ClientConfig } from "commerce-sdk";
* // or
* const { Pricing, ClientConfig } = require("commerce-sdk");
*
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
*
* token = { access_token: 'INSERT_ACCESS_TOKEN_HERE' };
*
* clientConfig.headers['authorization'] = `Bearer ${token.access_token}`;
* const couponsClient = new Pricing.Coupons(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.0.27<br />
* Last Updated: <br />
* </span>

*

*/
class Coupons extends core_1.BaseClient {
  /**
   *
   */
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/pricing/coupons/{version}";
    }
  }
  /**
    * Searches for coupons.

 The Coupon Search document contains a search object that allows filtering on various attributes.

 The query attribute specifies a complex query that can be used to narrow down the search with the following searchable attributes:
 
| Attribute | Type |
|-----------|--------|
| couponId| String |
| description | String |
| type | one of \{\"single_code\", \"multiple_codes\", \"system_codes\"\} |
| enabled | Boolean |

 Note that only searchable attributes can be used in sorting.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Coupons.CouponSearchResult otherwise.
    *
    */
  couponsSearch(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Searches for coupon redemptions.

The Coupon Redemption Search document contains a search object that allows filtering on various attributes.


The query attribute specifies a complex query that can be used to narrow down the search with the following searchable attributes:

  | Attribute | Type |
  |-----------|--------|
  | code| String |
  | couponId | String |
  | customerEmail | String |
  | orderNo | String |

Note that only searchable attributes can be used in sorting.

If the user role does not have the `View_Coupon_Codes` permission, then the coupon codes returned are masked.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Coupons.CouponRedemptionSearchResult otherwise.
    *
    */
  couponRedemptionsSearch(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/redemptions",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Redeems a coupon code for an existing coupon within the selected site.
The coupon code must be redeemable.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
    *
    */
  redeemCoupon(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/actions/redeem",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Delete a coupon by ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  deleteCoupon(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      couponId: optionParams["couponId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/{couponId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Returns coupon information for the given coupon ID.
 If the user role does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Coupons.Coupon otherwise.
    *
    */
  getCoupon(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      couponId: optionParams["couponId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/{couponId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates the coupon with the specified information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type Coupons.Coupon otherwise.
   *
   */
  updateCoupon(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      couponId: optionParams["couponId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/{couponId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Creates a coupon using the information provided. If a coupon exists with the same unique identifier,
 the coupon is replaced completely.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Coupons.Coupon otherwise.
    *
    */
  createCoupon(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      couponId: optionParams["couponId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.put(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/{couponId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Get the coupon codes for the given coupon.

 If the user role does not have the View_Coupon_Codes permission, then the coupon codes returned are masked.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param couponId - The ID of the coupon to create.
    * @param offset -
    * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 25.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type Coupons.CouponCodes otherwise.
    *
    */
  getCouponCodes(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      couponId: optionParams["couponId"],
    };
    const queryParams = {};
    if (optionParams["offset"] !== undefined) {
      queryParams["offset"] = optionParams["offset"];
    } else if (configParams["offset"] !== undefined) {
      queryParams["offset"] = configParams["offset"];
    }
    if (optionParams["limit"] !== undefined) {
      queryParams["limit"] = optionParams["limit"];
    } else if (configParams["limit"] !== undefined) {
      queryParams["limit"] = configParams["limit"];
    }
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/{couponId}/codes",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Add or delete (modify) multiple codes to and from the supplied coupon.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param couponId - The ID of the coupon to create.
   * @param delete - Pass as true to delete the passed codes.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   *
   */
  updateCouponCodes(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      couponId: optionParams["couponId"],
    };
    const queryParams = {};
    if (optionParams["delete"] !== undefined) {
      queryParams["delete"] = optionParams["delete"];
    } else if (configParams["delete"] !== undefined) {
      queryParams["delete"] = configParams["delete"];
    }
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/coupons/{couponId}/codes",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
}
exports.Coupons = Coupons;
//# sourceMappingURL=coupons.js.map
