/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GiftCertificates = void 0;
const core_1 = require("@commerce-apps/core");
const USER_AGENT_HEADER = "user-agent";
const USER_AGENT_VALUE = "commerce-sdk@3.1.0;";
/**
* [Gift Certificates](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=gift-certificates:Summary)
* ==================================
*
* *Manage your gift certificates.*<br />
*
*
* For instructions on how to retrieve access token for admin APIs: <a>https://developer.salesforce.com/docs/commerce/commerce-api/guide/authorization-for-admin-apis.html</a><br/><br/>
* Example with admin auth
*
* ```typescript
* import { Pricing, ClientConfig } from "commerce-sdk";
* // or
* const { Pricing, ClientConfig } = require("commerce-sdk");
*
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
*
* token = { access_token: 'INSERT_ACCESS_TOKEN_HERE' };
*
* clientConfig.headers['authorization'] = `Bearer ${token.access_token}`;
* const giftCertificatesClient = new Pricing.GiftCertificates(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.0.29<br />
* Last Updated: <br />
* </span>

*

*/
class GiftCertificates extends core_1.BaseClient {
  /**
   *
   */
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/pricing/gift-certificates/{version}";
    }
  }
  /**
    * Creates a gift certificate using the information provided. If a gift certificate with
 the same unique identifier is generated, it is deleted and a new one is created.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type GiftCertificates.GiftCertificate otherwise.
    *
    */
  createGiftCertificate(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.put(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/gift-certificates",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Searches for gift certificates. The query attribute specifies a complex query that can be used to narrow down the search. These are the list of searchable attributes:
 
| Attribute | Type | Sortable |
|-----------|--------|----------|
| merchantId | String | yes |
| maskedGiftCertificateCode * | String | no |
| orderNo | String | yes |
| senderName | String | yes |
| recipientName | String | yes |
| recipientEmail | String | yes |
| status | String | yes |
| enabled | Boolean | yes |
| message | String | yes |
| description | String | yes |
| creationDate | Date | yes |
| currencyMnemonic ** | String | yes |
 
## Notes:
  * *`maskedGiftCertificateCode`, also known as just code, can only be used in a term query.  If a
 four-character code is supplied, it is assumed that the search is on the unmasked portion of the code, otherwise
 the full code must be matched.  Text queries are not allowed.
  * **`currencyMnemonic` can only be joined with other attributes using a conjunction (`AND`).
  * Only searchable attributes can be used in sorting.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type GiftCertificates.GiftCertificateSearchResult otherwise.
    *
    */
  giftCertificatesSearch(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.post(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/gift-certificates",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Deletes the gift certificate by merchant ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param merchantId - The merchant ID of the requested gift certificate.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type GiftCertificates.GiftCertificate otherwise.
   *
   */
  deleteGiftCertificate(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      merchantId: optionParams["merchantId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.delete(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/gift-certificates/{merchantId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Action to get gift certificate information using merchant ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param merchantId - The merchant ID of the requested gift certificate.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type GiftCertificates.GiftCertificate otherwise.
   *
   */
  getGiftCertificate(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      merchantId: optionParams["merchantId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/gift-certificates/{merchantId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
   * Updates the gift certificate with the specified information using merchant ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId - An identifier for the organization the request is being made by.
   * @param merchantId - The merchant ID of the requested gift certificate.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type GiftCertificates.GiftCertificate otherwise.
   *
   */
  updateGiftCertificate(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
      merchantId: optionParams["merchantId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      "Content-Type": "application/json",
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.patch(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/gift-certificates/{merchantId}",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
          body: (options || {}).body,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
}
exports.GiftCertificates = GiftCertificates;
//# sourceMappingURL=giftCertificates.js.map
