/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShopperStores = void 0;
const core_1 = require("@commerce-apps/core");
const USER_AGENT_HEADER = "user-agent";
const USER_AGENT_VALUE = "commerce-sdk@3.1.0;";
/**
* [Shopper Stores](https://developer.salesforce.com/docs/commerce/commerce-api/references?meta=shopper-stores:Summary)
* ==================================
*
* *Search for a specific store or stores in an area.*<br />
*
*
* Example with shopper auth
*
* ```typescript
* import { Seller, ClientConfig, Customer, slasHelpers } from "commerce-sdk";
* // or
* const { Seller, ClientConfig, Customer, slasHelpers } = require("commerce-sdk");
*
* const clientConfig: ClientConfig = {
*   parameters: {
*     clientId: "XXXXXX",
*     organizationId: "XXXX",
*     shortCode: "XXX",
*     siteId: "XX"
*   }
* };
*
* // must be registered in SLAS. On server, redirectURI is never called
* const redirectURI = "http://localhost:3000/callback";
* const slasClient = new Customer.ShopperLogin(clientConfig);
* token = await slasHelpers.loginGuestUser(slasClient, { redirectURI });
*
* clientConfig.headers['authorization'] = `Bearer ${token.access_token}`;
* const shopperStoresClient = new Seller.ShopperStores(clientConfig);
* ```
*
* <span style="font-size:.7em; display:block; text-align: right">
* API Version: 1.0.15<br />
* Last Updated: <br />
* </span>
* @beta
*
*

*/
class ShopperStores extends core_1.BaseClient {
  /**
   *
   */
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      this.clientConfig.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/store/shopper-stores/{version}";
    }
  }
  /**
    * This resource retrieves a list of stores for the given site that are within a configured distance of a geolocation:
- The distance is interpreted either in miles or kilometers, depending on the `distanceUnit` input parameter.
- The location is specified by either directly providing a latitude and longitude coordinate pair, or by providing a country and a postal code. If a postal code is passed, the resource looks in the system's geolocation mappings in Business Manager to find the coordinates for this postal code. If no matching geolocation is found, the resource returns an empty list of stores. If coordinates are passed, the values for country and postal code are ignored.

  To verify site latitude and longitude information in Business Manager:
  - Navigate to **Merchant Tools -\> Online Marketing -\> Stores**.
  - Select the applicable site.
  - In the **Address** tab, verify that valid information is provided in the following fields: **Address**, **City**, **Postal Code**, **State**, and **Country**. For latitude and longitude values, you can manually enter values or provide all field values to auto-populate **Latitude** and **Longitude**. You must provide valid values for all of the previous fields for latitude and longitude to auto-populate **Latitude** and **Longitude** values.

    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param countryCode - The two letter ISO country code, such as "US". This value is required when a postalCode is provided.
    * @param distanceUnit - The distance unit. Supported values are "mi" (miles) and "km" (kilometers). The default is "km".
    * @param latitude - The geographical latitude to search for stores (value range -90.00 .. 90.00). This value is required when a longitude is provided.
    * @param longitude - The geographical longitude to search for stores (value range -180.00 .. 180.00). You must provide a longitude when a latitude is provided.
    * @param maxDistance - The area (radius) in distanceUnit where stores will be searched.
    * @param postalCode - The postal code, such as "84121". You must provide a countryCode when a postalCode is provided.
    * @param siteId -
    * @param locale - A descriptor to provide locale context for a geographical region by both a language and/or country code. The locale pattern in the query param follows the ISO 639-1 for the language code (e.g. en, de, fr) and ISO 3166-1 for the country code (e.g. US, DE, AT). The param can be a combination of language code and country code or can just refer to the language code.
Below are some valid examples:
- en-US
- de-AT
- de
- default
    * @param offset -
    * @param limit - Maximum records to retrieve per request, not to exceed 200. Defaults to 25.
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperStores.StoreResult otherwise.
    *
    * @beta
    *
    */
  searchStores(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["countryCode"] !== undefined) {
      queryParams["countryCode"] = optionParams["countryCode"];
    } else if (configParams["countryCode"] !== undefined) {
      queryParams["countryCode"] = configParams["countryCode"];
    }
    if (optionParams["distanceUnit"] !== undefined) {
      queryParams["distanceUnit"] = optionParams["distanceUnit"];
    } else if (configParams["distanceUnit"] !== undefined) {
      queryParams["distanceUnit"] = configParams["distanceUnit"];
    }
    if (optionParams["latitude"] !== undefined) {
      queryParams["latitude"] = optionParams["latitude"];
    } else if (configParams["latitude"] !== undefined) {
      queryParams["latitude"] = configParams["latitude"];
    }
    if (optionParams["longitude"] !== undefined) {
      queryParams["longitude"] = optionParams["longitude"];
    } else if (configParams["longitude"] !== undefined) {
      queryParams["longitude"] = configParams["longitude"];
    }
    if (optionParams["maxDistance"] !== undefined) {
      queryParams["maxDistance"] = optionParams["maxDistance"];
    } else if (configParams["maxDistance"] !== undefined) {
      queryParams["maxDistance"] = configParams["maxDistance"];
    }
    if (optionParams["postalCode"] !== undefined) {
      queryParams["postalCode"] = optionParams["postalCode"];
    } else if (configParams["postalCode"] !== undefined) {
      queryParams["postalCode"] = configParams["postalCode"];
    }
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    if (optionParams["locale"] !== undefined) {
      queryParams["locale"] = optionParams["locale"];
    } else if (configParams["locale"] !== undefined) {
      queryParams["locale"] = configParams["locale"];
    }
    if (optionParams["offset"] !== undefined) {
      queryParams["offset"] = optionParams["offset"];
    } else if (configParams["offset"] !== undefined) {
      queryParams["offset"] = configParams["offset"];
    }
    if (optionParams["limit"] !== undefined) {
      queryParams["limit"] = optionParams["limit"];
    } else if (configParams["limit"] !== undefined) {
      queryParams["limit"] = configParams["limit"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/store-search",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
  /**
    * Returns stores identified by the IDs provided as input.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId - An identifier for the organization the request is being made by.
    * @param siteId -
    * @param ids - The IDs of a requested stores (comma separated, max 50 IDs).
    * @param locale - A descriptor to provide locale context for a geographical region by both a language and/or country code. The locale pattern in the query param follows the ISO 639-1 for the language code (e.g. en, de, fr) and ISO 3166-1 for the country code (e.g. US, DE, AT). The param can be a combination of language code and country code or can just refer to the language code.
Below are some valid examples:
- en-US
- de-AT
- de
- default
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ShopperStores.StoreResult otherwise.
    *
    * @beta
    *
    */
  getStores(options, rawResponse) {
    const optionParams =
      (options === null || options === void 0 ? void 0 : options.parameters) ||
      {};
    const configParams = this.clientConfig.parameters;
    const pathParams = {
      organizationId:
        optionParams["organizationId"] !== undefined
          ? optionParams["organizationId"]
          : configParams["organizationId"],
    };
    const queryParams = {};
    if (optionParams["siteId"] !== undefined) {
      queryParams["siteId"] = optionParams["siteId"];
    } else if (configParams["siteId"] !== undefined) {
      queryParams["siteId"] = configParams["siteId"];
    } else {
      throw new Error("Missing required query parameter: siteId");
    }
    if (optionParams["ids"] !== undefined) {
      queryParams["ids"] = optionParams["ids"];
    } else if (configParams["ids"] !== undefined) {
      queryParams["ids"] = configParams["ids"];
    } else {
      throw new Error("Missing required query parameter: ids");
    }
    if (optionParams["locale"] !== undefined) {
      queryParams["locale"] = optionParams["locale"];
    } else if (configParams["locale"] !== undefined) {
      queryParams["locale"] = configParams["locale"];
    }
    Object.keys(optionParams).forEach((key) => {
      if (key.startsWith("c_") && optionParams[key] !== undefined) {
        queryParams[key] = optionParams[key];
      } else if (
        !queryParams.hasOwnProperty(key) &&
        !pathParams.hasOwnProperty(key)
      ) {
        console.warn(`Invalid Parameter: ${key}`);
      }
    });
    const headers = (0, core_1.mergeHeaders)((0, core_1.getHeaders)(options), {
      [USER_AGENT_HEADER]: USER_AGENT_VALUE,
    });
    return core_1.StaticClient.get(
      Object.assign(
        {
          client: this,
          rawResponse: rawResponse,
          path: "/organizations/{organizationId}/stores",
          pathParameters: pathParams,
          queryParameters: queryParams,
          retrySettings: (options || {}).retrySettings,
          headers: headers,
        },
        options.fetchOptions && { fetchOptions: options.fetchOptions }
      )
    );
  }
}
exports.ShopperStores = ShopperStores;
//# sourceMappingURL=shopperStores.js.map
